#!/usr/bin/python3
## system-config-printer

## Copyright (C) 2008, 2009, 2010 Red Hat, Inc.
## Authors:
##  Tim Waugh <twaugh@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

import config
import gettext
gettext.install(domain=config.PACKAGE, localedir=config.localedir)

printer_error_policy = dict()
printer_op_policy = dict()
job_sheets = dict()
job_options = dict()
ppd = dict()
backends = dict()

class TranslationDict:
    STR = {}

    def __init__ (self, d):
        self.STR = d

    def get (self, str):
        return self.STR.get (str, str)

def init ():
    ## IPP strings

    # Names of printer error policies
    global printer_error_policy
    printer_error_policy = TranslationDict ({
            "abort-job": _("Abort job"),
            "retry-current-job": _("Retry current job"),
            "retry-job": _("Retry job"),
            "stop-printer": _("Stop printer")
            })
    
    # Names of printer operation policies
    global printer_op_policy
    printer_op_policy = TranslationDict ({
            "default": _("Default behavior"),
            "authenticated": _("Authenticated")
            })

    # Names of banner pages.
    global job_sheets
    job_sheets = TranslationDict ({
            "none": _("None"),
            "classified": _("Classified"),
            "confidential": _("Confidential"),
            "secret": _("Secret"),
            "standard": _("Standard"),
            "topsecret": _("Top secret"),
            "unclassified": _("Unclassified")
            })

    # Names of job-hold-until values.
    global job_options
    job_options["job-hold-until"] = TranslationDict ({
            "no-hold": _("No hold"),
            "indefinite": _("Indefinite"),
            "day-time": _("Daytime"),
            "evening": _("Evening"),
            "night": _("Night"),
            "second-shift": _("Second shift"),
            "third-shift": _("Third shift"),
            "weekend": _("Weekend")
            })

    ## Common PPD strings

    # Foomatic strings

    # These are PPD option and group names and values.
    global ppd
    ppd = TranslationDict ({
            "General": _("General"),

            # HPIJS options
            "Printout Mode": _("Printout mode"),
            "Draft (auto-detect paper type)":
                _("Draft (auto-detect-paper type)"),
            "Draft Grayscale (auto-detect paper type)":
                _("Draft grayscale (auto-detect-paper type)"),
            "Normal (auto-detect paper type)":
                _("Normal (auto-detect-paper type)"),
            "Normal Grayscale (auto-detect paper type)":
                _("Normal grayscale (auto-detect-paper type)"),
            "High Quality (auto-detect paper type)":
                _("High quality (auto-detect-paper type)"),
            "High Quality Grayscale (auto-detect paper type)":
                _("High quality grayscale (auto-detect-paper type)"),
            "Photo (on photo paper)": _("Photo (on photo paper)"),
            "Best Quality (color on photo paper)":
                _("Best quality (color on photo paper)"),
            "Normal Quality (color on photo paper)":
                _("Normal quality (color on photo paper)"),
            ###########new translation
            "Letter": _("Letter"),
            "US Letter": _("US Letter"),
            "US Legal": _("US Legal"),
            "Executive": _("Executive"),
            "Envelope #10": _("Envelope #10"),
            "Envelope Monarch": _("Envelope Monarch"),
            "Envelope C5": _("Envelope C5"),
            "Envelope DL": _("Envelope DL"),
            "Envelope B5": _("Envelope B5"),
            "Envelope C6": _("Envelope C6"),
            "Envelope Personal": _("Envelope Personal"),
            "Envelope #9": _("Envelope #9"),
            "US Ledger": _("US Ledger"),
            "Postcard": _("Postcard"),
            "Postcard Double Long Edge": _("Postcard Double Long Edge"),
            
            "Air pressure": _("Air pressure"),
            "High": _("High"),
            "Low": _("Low"),
            "Automatic Selection": _("Automatic Selection"),
            "Manual Feed": _("Manual Feed"),
            "Multi-Purpose Tray": _("Multi-Purpose Tray"),
            "Envelope Tray": _("Envelope Tray"),
            "Tray": _("Tray"),
            "Paper Type": _("Paper Type"),
            "Use Printer Default": _("Use Printer Default"),
            "Plain Paper": _("Plain Paper"),
            "Thick Paper": _("Thick Paper"),
            "Thin Paper": _("Thin Paper"),
            "Bond": _("Bond"),
            "Transparency": _("Transparency"),
            "Card Stock": _("Card Stock"),
            "Label": _("Label"),
            "Preprinted": _("Preprinted"),
            "Colored Paper": _("Colored Paper"),
            "Cotton": _("Cotton"),
            "Recycled": _("Recycled"),
            "Archive": _("Archive"),
            "Power Save": _("Power Save"),
            "Toner Density": _("Toner Density"),
            "5 Minutes": _("5 Minutes"), 
            "10 Minutes": _("10 Minutes"), 
            "15 Minutes": _("15 Minutes"), 
            "30 Minutes": _("30 Minutes"), 
            "45 Minutes": _("45 Minutes"), 
            "1 Hour": _("1 Hour"), 
            "Light": _("Light"), 
            "Medium": _("Medium"), 
            "Dark": _("Dark"), 
            "Toner Save": _("Toner Save"), 
            "Save": _("Save"), 
            "Standard": _("Standard"),
            "Reprint When Jam": _("Reprint When Jam"), 
            "Color Mode": _("Color Mode"), 
            "Grayscale": _("Grayscale"), 
            "SRT Mode": _("SRT Mode"), 
            "Normal": _("Normal"), 
            "Text enhance": _("Text enhance"), 
            "Image enhance": _("Image enhance"),
            "Off (1-Sided)": _("Off (1-Sided)"),
            "Long-Edge (Portrait)": _("Long-Edge (Portrait)"),
            "Short-Edge (Landscape)": _("Short-Edge (Landscape)"),
            "Laminate Pattern": _("Laminate Pattern"),
            "Media Size": _("Media Size"),
            "Color Model": _("Color Model"),
            "Color Precision": _("Color Precision"),
            "Media Type": _("Media Type"),
            "Print Quality": _("Print Quality"),
            "Resolution": _("Resolution"),
            "2-Sided Printing": _("2-Sided Printing"),
            "Shrink Page If Necessary to Fit Borders": _("Shrink Page If Necessary to Fit Borders"),
            "Printer Features Common": _("Printer Features Common"),
            "Ink Type": _("Ink Type"),
            "Ink Set": _("Ink Set"),
            "Borderless": _("Borderless"),
            "Output Control Common": _("Output Control Common"),
            "Color Correction": _("Color Correction"),
            "Brightness": _("Brightness"),
            "Brightness Fine Adjustment": _("Brightness Fine Adjustment"),
            "Contrast": _("Contrast"),
            "Contrast Fine Adjustment": _("Contrast Fine Adjustment"),
            "Saturation": _("Saturation"),
            "Saturation Fine Adjustment": _("Saturation Fine Adjustment"),
            "Image Type": _("Image Type"),
            "Output Control Extra 1": _("Output Control Extra 1"),
            "Cyan Density": _("Cyan Density"),
            "Cyan Density Fine Adjustment": _("Cyan Density Fine Adjustment"),
            "Magenta Density": _("Magenta Density"),
            "Magenta Density Fine Adjustment": _("Magenta Density Fine Adjustment"),
            "Yellow Density": _("Yellow Density"),
            "Yellow Density Fine Adjustment": _("Yellow Density Fine Adjustment"),
            "Black Density": _("Black Density"),
            "Black Density Fine Adjustment": _("Black Density Fine Adjustment"),
            "Density": _("Density"),
            "Density Fine Adjustment": _("Density Fine Adjustment"),
            "Dither Algorithm": _("Dither Algorithm"),
            "Output Control Extra 2": _("Output Control Extra 2"),
            "Composite Gamma": _("Composite Gamma"),
            "Composite Gamma Fine Adjustment": _("Composite Gamma Fine Adjustment"),
            "Cyan": _("Cyan"),
            "Cyan Fine Adjustment": _("Cyan Fine Adjustment"),
            "Magenta": _("Magenta"),
            "Magenta Fine Adjustment": _("Magenta Fine Adjustment"),
            "Yellow": _("Yellow"),
            "Yellow Fine Adjustment": _("Yellow Fine Adjustment"),
            "Black": _("Black"),
            "Black Fine Adjustment": _("Black Fine Adjustment"),
            "Cyan Balance": _("Cyan Balance"),
            "Cyan Balance Fine Adjustment": _("Cyan Balance Fine Adjustment"),
            "Magenta Balance": _("Magenta Balance"),
            "Magenta Balance Fine Adjustment": _("Magenta Balance Fine Adjustment"),
            "Yellow Balance": _("Yellow Balance"),
            "Yellow Balance Fine Adjustment": _("Yellow Balance Fine Adjustment"),
            "Output Control Extra 4": _("Output Control Extra 4"),
            "Linear Contrast Adjustment": _("Linear Contrast Adjustment"),
            "Output Control Extra 5": _("Output Control Extra 5"),
            "Light Cyan Transition": _("Light Cyan Transition"),
            "Light Cyan Transition Fine Adjustment": _("Light Cyan Transition Fine Adjustment"),
            "Light Magenta Transition": _("Light Magenta Transition"),
            "Light Magenta Transition Fine Adjustment": _("Light Magenta Transition Fine Adjustment"),
            "Light Yellow Transition": _("Light Yellow Transition"),
            "Light Yellow Transition Fine Adjustment": _("Light Yellow Transition Fine Adjustment"),
            "Ink Limit": _("Ink Limit"),
            "Ink Limit Fine Adjustment": _("Ink Limit Fine Adjustment"),
            "GCR Transition": _("GCR Transition"),
            "GCR Transition Fine Adjustment": _("GCR Transition Fine Adjustment"),
            "GCR Lower Bound": _("GCR Lower Bound"),
            "GCR Lower Bound Fine Adjustment": _("GCR Lower Bound Fine Adjustment"),
            "GCR Upper Bound": _("GCR Upper Bound"),
            "GCR Upper Bound Fine Adjustment": _("GCR Upper Bound Fine Adjustment"),
            ####################################################################
            "Grayscale": _("Grayscale"),
            "Inverted Grayscale": _("Inverted Grayscale"),
            "RGB Color": _("RGB Color"),
            "CMY Color": _("CMY Color"),
            "CMYK": _("CMYK"),
            "KCMY": _("KCMY"),
            "Normal": _("Normal"),
            "Best": _("Best"),
            
            "Shrink(print the whole page)": _("Shrink(print the whole page)"),
            "Crop(preserve dimensions)": _("Crop(preserve dimensions)"),
            "Expand(use maximum page area)": _("Expand(use maximum page area)"),
            "Glossy": _("Glossy"),
            "Matte": _("Matte"),
            "Default": _("Default"),
            "High Accuracy": _("High Accuracy"),
            "Bright Colors": _("Bright Colors"),

            "Correct Hue Only": _("Correct Hue Only"),
            "Uncorrected": _("Uncorrected"),
            "Desaturated": _("Desaturated"),
            "Threshold": _("Threshold"),
            "Raw": _("Raw"),
            "Pre-Dithered": _("Pre-Dithered"),
            "Manual Control": _("Manual Control"),
            "Text": _("Text"),

            "Graphics": _("Graphics"),
            "Mixed Text and Graphics": _("Mixed Text and Graphics"),
            "Photograph": _("Photograph"),
            "Line Art": _("Line Art"),
            "None": _("None"),
            "EvenTone": _("EvenTone"),
            "Hybrid EvenTone": _("Hybrid EvenTone"),
            "Adaptive Hybrid": _("Adaptive Hybrid"),

            "Ordered": _("Ordered"),
            "Ordered New": _("Ordered New"),
            "Fast": _("Fast"),
            "Very Fast": _("Very Fast"),
            "Hybrid Floyd-Steinberg": _("Hybrid Floyd-Steinberg"),
            "Predithered Input": _("Predithered Input"),
            "Drop Size Segmented": _("Drop Size Segmented"),
            "Drop Size Segmented New": _("Drop Size Segmented New"),

            "Cyan Balance": _("Cyan Balance"),
            "No": _("No"),
            "Yes": _("Yes"),
            "Letter": _("Letter"),
            "US Letter": _("US Letter"),
            "Postcard": _("Postcard"),
            "Colour Depth:": _("Colour Depth:"),
            "Color Mode:": _("Color Mode:"),

            "Dithering:": _("Dithering:"),
            "On": _("On"),
            "Plain Paper": _("Plain Paper"),
            "Cardboard": _("Cardboard"),
            "Coated Film": _("Coated Film"),
            "Fine Paper": _("Fine Paper"),
            "Glossy Paper": _("Glossy Paper"),
            "Iron Seal": _("Iron Seal"),

            "OHP": _("OHP"),
            "OHP(MD 2000)": _("OHP(MD 2000)"),
            "Rebeca Free": _("Rebeca Free"),
            "Manual Feed of Paper": _("Manual Feed of Paper"),
            "Black color saving": _("Black color saving"),
            "Adjustment": _("Adjustment"),
            "Black Level": _("Black Level"),
            "Cyan Level": _("Cyan Level"),

            "Magenta Level": _("Magenta Level"),
            "Yellow Level": _("Yellow Level"),
            "US standard Fanfold(14.875x11)": _("US standard Fanfold(14.875x11)"),
            "German Standard Fanfold(8.5x12)": _("German Standard Fanfold(8.5x12)"),
            "US Legal": _("US Legal"),
            "Super B(13x19)": _("Super B(13x19)"),
            "Envelope #10": _("Envelope #10"),
            "Envelope C5": _("Envelope C5"),

            "Envelope DL": _("Envelope DL"),
            "Envelope B5": _("Envelope B5"),
            "Envelope Monarch": _("Envelope Monarch"),
            "Executive": _("Executive"),
            ###################################################################
            ##########end new translation
            "Media Source": _("Media source"),
            "Printer default": _("Printer default"),
            "Photo Tray": _("Photo tray"),
            "Upper Tray": _("Upper tray"),
            "Lower Tray": _("Lower tray"),
            "CD or DVD Tray": _("CD or DVD tray"),
            "Envelope Feeder": _("Envelope feeder"),
            "Large Capacity Tray": _("Large capacity tray"),
            "Manual Feeder": _("Manual feeder"),
            "Multi Purpose Tray": _("Multi-purpose tray"),

            "Page Size": _("Page size"),
            "Custom": _("Custom"),
            "Photo or 4x6 inch index card": _("Photo or 4x6 inch index card"),
            "Photo or 5x7 inch index card": _("Photo or 5x7 inch index card"),
            "Photo with tear-off tab": _("Photo with tear-off tab"),
            "3x5 inch index card": _("3x5 inch index card"),
            "5x8 inch index card": _("5x8 inch index card"),
            "A6 with tear-off tab": _("A6 with tear-off tab"),
            "CD or DVD 80 mm": _("CD or DVD 80mm"),
            "CD or DVD 120 mm": _("CD or DVD 120mm"),

            "Double-Sided Printing": _("Double-sided printing"),
            "Long Edge (Standard)": _("Long edge (standard)"),
            "Short Edge (Flip)": _("Short edge (flip)"),
            "Off": _("Off"),

            "Resolution, Quality, Ink Type, Media Type":
                _("Resolution, quality, ink type, media type"),
            "Controlled by 'Printout Mode'": _("Controlled by 'Printout mode'"),
            "300 dpi, Color, Black + Color Cartr.":
                _("300 dpi, color, black + color cartridge"),
            "300 dpi, Draft, Color, Black + Color Cartr.":
                _("300 dpi, draft, color, black + color cartridge"),
            "300 dpi, Draft, Grayscale, Black + Color Cartr.":
                _("300 dpi, draft, grayscale, black + color cartridge"),
            "300 dpi, Grayscale, Black + Color Cartr.":
                _("300 dpi, grayscale, black + color cartridge"),
            "600 dpi, Color, Black + Color Cartr.":
                _("600 dpi, color, black + color cartridge"),
            "600 dpi, Grayscale, Black + Color Cartr.":
                _("600 dpi, grayscale, black + color cartridge"),
            "600 dpi, Photo, Black + Color Cartr., Photo Paper":
                _("600 dpi, photo, black + color cartridge, photo paper"),
            "600 dpi, Color, Black + Color Cartr., Photo Paper, Normal":
                _("600 dpi, color, black + color cartridge, photo paper, normal"),
            "1200 dpi, Photo, Black + Color Cartr., Photo Paper":
                _("1200 dpi, photo, black + color cartridge, photo paper"),
            })

    ## Common backend descriptions
    global backends
    backends = TranslationDict ({
            "Internet Printing Protocol (ipp)":
                _("Internet Printing Protocol (ipp)"),
            "Internet Printing Protocol (ipps)":
                _("Internet Printing Protocol (ipps)"),
            "Internet Printing Protocol (ipp14)":
                _("Internet Printing Protocol (ipp14)"),
            "Internet Printing Protocol (http)":
                _("Internet Printing Protocol (http)"),
            "Internet Printing Protocol (https)":
                _("Internet Printing Protocol (https)"),
            "LPD/LPR Host or Printer":
                _("LPD/LPR Host or Printer"),
            "AppSocket/HP JetDirect":
                _("AppSocket/HP JetDirect"),
            "Serial Port #1":
                _("Serial Port #1"),
            "Serial Port #2":
                _("Serial Port #2"),
            "LPT #1":
                _("LPT #1"),
            "Windows Printer via SAMBA":
                _("Windows Printer via SAMBA"),
            })
